Author: Official UK Chicco website

- contacts

# Contacts

In this section you can send us your personal requests for information or any recommendations. Fill out the following form with all your personal data to allow us to contact you faster.
The Chicco Customer Service will answer you as soon as possible.
Thank you for contacting Chicco UK part of Artsana Group.
Shortly you will receive an email confirmation and response to your message.
If you do not receive confirmation, please contact us via our Consumer Care Team who are available Monday to Friday, from 09.00 to 17.00 pm.
Customer Service Artsana.
Call
Send SMS
Add to Skype
You'll need Skype CreditFree via Skype
There was an error sending this e-mail. Please try again.
There was an error sending this e-mail.

Message*
I have read and accepted the foregoing Informative Note and consent to the processing of my personal data for the purposes specified therein.*
Captcha *

Chicco UK part of ARTSANA S.P.A.
Head Office:
Building 1, 2nd Floor, Imperial Place, Maxwell Road, Borehamwood, Hertfordshire.
WD6 1JN
Head Office: 02089536627
Warehouse, Orders & Finance:
Unit C, Parkway, Oddicroft Lane, Sutton in Ashfield.
NG17 5FB
Office: +44 1623 750870
Fax: +44 1623 723880